jaclearn.visualize.box
======================

.. automodule:: jaclearn.visualize.box

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      add_bbox_patches
      vis_bboxes
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: add_bbox_patches

.. autofunction:: vis_bboxes


